# Transaction settlement abci

## Description

This module contains the ABCI transaction settlement skill for an AEA.

## Behaviours

* `BaseResetBehaviour`

   Reset state.

* `FinalizeBehaviour`

   Finalize state.

* `RandomnessTransactionSubmissionBehaviour`

   Retrieve randomness.

* `ResetAndPauseBehaviour`

   Reset and pause state.

* `ResetBehaviour`

   Reset state.

* `SelectKeeperTransactionSubmissionBehaviourA`

   Select the keeper agent.

* `SelectKeeperTransactionSubmissionBehaviourB`

   Select the keeper agent.

* `SignatureBehaviour`

   Signature state.

* `TransactionSettlementBaseState`

   Base state behaviour for the common apps' skill.

* `ValidateTransactionBehaviour`

   Validate a transaction.


## Handlers

No Handlers (the skill is purely behavioural).

